//// -------------------------------------------------------------------------
//// File     : DDEDTEXT.DCL
//// Copyright: cad nauseam, 1995.  Shareware: see DDEDTEXT.TXT for details.
//// Author   : Steve Johnson
//// Purpose  : Dialogue box definition for DDEDTEXT command when editing
////            dimension and mtext entities.
//// Notes    : User-modifiable items are indicated with **
//// Version  : 2.02
//// Date     : 28 September 1995
//// -------------------------------------------------------------------------


/// --------------------------------------------------------------------------
/// Turn off error checking
/// --------------------------------------------------------------------------

dcl_settings : default_dcl_settings { audit_level = 0; }


/// --------------------------------------------------------------------------
/// Widget: ddedtext
/// This is the main dialogue box.
/// --------------------------------------------------------------------------

ddedtext : dialog {
  key                   = "title";
  initial_focus         = "text";

// ---------------------------------------------------------------------------
// ** You can modify the character used to define the insertion point for the
// text to insert, by changing the contents of this item:
  insert_string         = "`";
// ---------------------------------------------------------------------------

  dded_buttons;

// ---------------------------------------------------------------------------
// ** To add extra rows of buttons, remove the double slashes // from the
// start of one or both of the next two lines:
//  insert_2;
//  insert_3;
// You can modify the contents of these rows, see insert_2 and insert_3 below.
// ---------------------------------------------------------------------------

  : text {
    key                 = "original";
  }
  : edit_box {
    label               = "Edited:";
    key                 = "text";
    edit_width          = 65;
    edit_limit          = 250;
    allow_accept        = true;
  }
  spacer;
  full_ok_cancel;
} // end ddedtext


/// --------------------------------------------------------------------------
/// Widget: dded_buttons
/// Row of buttons above text.
/// --------------------------------------------------------------------------

dded_buttons : row {
  alignment             = centered;
  : fixed_button {
    label               = "Change case";
    key                 = "case";
  }

// ---------------------------------------------------------------------------
// ** The following 3 buttons can be modified, as described in DDEDTEXT.TXT
  : fixed_button {
    key                 = "insert_1";
    label               = "Degrees";
    mtext_string        = "\\U+00B0";
    text_string         = "%%d";
  }
  : fixed_button {
    key                 = "insert_2";
    label               = "Diameter";
    mtext_string        = "\\U+2205";
    text_string         = "%%c";
  }
  : fixed_button {
    key                 = "insert_3";
    label               = "+/-";
    mtext_string        = "\\U+00B1";
    text_string         = "%%p";
  }
  : fixed_button {
    label               = "User...";
    key                 = "user";
  }
// ---------------------------------------------------------------------------

} // end dded_buttons


/// --------------------------------------------------------------------------
/// Widgets: insert_2 and insert_3
/// ** Extra rows of buttons which can be used to provide instant access to
/// user-defined insert strings.  See DDEDTEXT.TXT for details of how to
/// change the buttons.
/// --------------------------------------------------------------------------

insert_2 : row {
  alignment             = centered;
  : fixed_button {
    key                 = "insert_4";
    label               = "Insert 4";
    mtext_string        = "4";
    text_string         = "4";
  }
  : fixed_button {
    key                 = "insert_5";
    label               = "Insert 5";
    mtext_string        = "5";
    text_string         = "5";
  }
  : fixed_button {
    key                 = "insert_6";
    label               = "Insert 6";
    mtext_string        = "6";
    text_string         = "6";
  }
  : fixed_button {
    key                 = "insert_7";
    label               = "Insert 7";
    mtext_string        = "7";
    text_string         = "7";
  }
  : fixed_button {
    key                 = "insert_8";
    label               = "Insert 8";
    mtext_string        = "8";
    text_string         = "8";
  }
} // end insert_2


insert_3 : row {
  alignment             = centered;
  : fixed_button {
    key                 = "insert_9";
    label               = "Insert 9";
    mtext_string        = "9";
    text_string         = "9";
  }
  : fixed_button {
    key                 = "insert_10";
    label               = "Insert 10";
    mtext_string        = "10";
    text_string         = "10";
  }
  : fixed_button {
    key                 = "insert_11";
    label               = "Insert 11";
    mtext_string        = "11";
    text_string         = "11";
  }
  : fixed_button {
    key                 = "insert_12";
    label               = "Insert 12";
    mtext_string        = "12";
    text_string         = "12";
  }
  : fixed_button {
    key                 = "insert_13";
    label               = "Insert 13";
    mtext_string        = "13";
    text_string         = "13";
  }
} // end insert_3


/// --------------------------------------------------------------------------
/// Widget: full_button
/// --------------------------------------------------------------------------

full_button : retirement_button {
  label                 = "Full editor...";
  key                   = "full";
} // end full_button


/// --------------------------------------------------------------------------
/// Widget: cancel_all
/// --------------------------------------------------------------------------

cancel_all : retirement_button {
  label                 = "Cancel all";
  key                   = "finish";
} // end cancel_all


/// --------------------------------------------------------------------------
/// Widget: full_ok_cancel
/// --------------------------------------------------------------------------

full_ok_cancel : column {
  : row {
    fixed_width         = true;
    alignment           = centered;

// ---------------------------------------------------------------------------
// Release 12 users may wish to remove the "Full editor..." button.
// To do this, place double slashes // at the start of the next two lines.
    full_button;
    : spacer { width    = 2; }
// ---------------------------------------------------------------------------

    ok_button;
    : spacer { width    = 2; }
    cancel_button;
    : spacer { width    = 2; }
    cancel_all;
  }
} // end full_ok_cancel


/// --------------------------------------------------------------------------
/// Widget: fixed_button
/// --------------------------------------------------------------------------

fixed_button : button {
  width                 = 13;
  fixed_width           = true;
} // end fixed_button
  

/// --------------------------------------------------------------------------
/// Widget: list_user
/// This is a sub dialogue box used to list the user-defined insert strings.
/// --------------------------------------------------------------------------

list_user : dialog {
  label                 = "User Text to Insert";
  : list_box {
    key                 = "list_box";
    width               = 50;
    height              = 22;
  }
  spacer;
  ok_cancel_err;
} // end list_user


//// -------------------------------------------------------------------------
//// End DDEDTEXT.DCL
//// -------------------------------------------------------------------------